# API Reference

> Auto-generated by MyWork AI Doc Generator

## /

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `tools/scaffold.py`

### `GET` /

**File:** `projects/big-project/backend/main.py`

### `GET` /

**File:** `projects/big-project/backend/main.py`

### `GET` /

**File:** `projects/blog-platform/backend/main.py`

### `GET` /

**File:** `projects/blog-platform/backend/main.py`

### `GET` /

**File:** `projects/api-hub/backend/main.py`

### `GET` /

**File:** `projects/api-hub/backend/main.py`

### `GET` /

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /

**File:** `projects/ai-dashboard/backend/main.py`

---

## /AUTOCODER_ROOT

### `GET` AUTOCODER_ROOT

**File:** `tools/config.py`

### `GET` AUTOCODER_ROOT

**File:** `tools/auto_update.py`

### `GET` AUTOCODER_ROOT

**File:** `tools/switch_llm_provider.py`

### `GET` AUTOCODER_ROOT

**File:** `tools/health_check.py`

---

## /AUTOCODER_SERVER

### `GET` AUTOCODER_SERVER

**File:** `tools/config.py`

---

## /AUTOFORGE_ROOT

### `GET` AUTOFORGE_ROOT

**File:** `tools/autocoder_service.py`

### `GET` AUTOFORGE_ROOT

**File:** `tools/autoforge_service.py`

---

## /Access-Control-Allow-Origin

### `GET` Access-Control-Allow-Origin

**File:** `tools/security/api_tester.py`

---

## /AutoForge Activation

### `GET` AutoForge Activation

**File:** `tools/simulation/user_journey.py`

---

## /CLI Experience

### `GET` CLI Experience

**File:** `tools/simulation/user_journey.py`

---

## /GSD Final Audit

### `GET` GSD Final Audit

**File:** `tools/simulation/user_journey.py`

---

## /MARKETPLACE_API_URL

### `GET` MARKETPLACE_API_URL

**File:** `tools/marketplace_upload_previews.py`

---

## /MARKETPLACE_BRAIN_TOKEN

### `GET` MARKETPLACE_BRAIN_TOKEN

**File:** `tools/brain_sync.py`

---

## /MARKETPLACE_BRAIN_URL

### `GET` MARKETPLACE_BRAIN_URL

**File:** `tools/brain_sync.py`

---

## /MARKETPLACE_PRODUCT_ID

### `GET` MARKETPLACE_PRODUCT_ID

**File:** `tools/marketplace_upload_previews.py`

---

## /MYWORK_ESCROW_DAYS

### `GET` MYWORK_ESCROW_DAYS

**File:** `tools/credits_ledger.py`

---

## /MYWORK_LEDGER_DIR

### `GET` MYWORK_LEDGER_DIR

**File:** `tools/credits_ledger.py`

---

## /MYWORK_ROOT

### `GET` MYWORK_ROOT

**File:** `tools/config.py`

### `GET` MYWORK_ROOT

**File:** `tools/mw.py`

### `GET` MYWORK_ROOT

**File:** `tools/autoforge_api.py`

### `GET` MYWORK_ROOT

**File:** `tools/project_archive.py`

### `GET` MYWORK_ROOT

**File:** `tools/autocoder_service.py`

### `GET` MYWORK_ROOT

**File:** `tools/auto_update.py`

### `GET` MYWORK_ROOT

**File:** `tools/switch_llm_provider.py`

### `GET` MYWORK_ROOT

**File:** `tools/scaffold.py`

### `GET` MYWORK_ROOT

**File:** `tools/autocoder_api.py`

### `GET` MYWORK_ROOT

**File:** `tools/workflow_engine.py`

### `GET` MYWORK_ROOT

**File:** `tools/health_check.py`

### `GET` MYWORK_ROOT

**File:** `tools/project_compare.py`

### `GET` MYWORK_ROOT

**File:** `tools/dep_checker.py`

### `GET` MYWORK_ROOT

**File:** `tools/brain_learner.py`

### `GET` MYWORK_ROOT

**File:** `tools/autoforge_service.py`

### `GET` MYWORK_ROOT

**File:** `tools/module_registry.py`

### `GET` MYWORK_ROOT

**File:** `tools/brain.py`

### `GET` MYWORK_ROOT

**File:** `tools/brain_semantic.py`

### `GET` MYWORK_ROOT

**File:** `tests/conftest.py`

### `GET` MYWORK_ROOT

**File:** `tools/skills/installed/security-scan/scan.py`

---

## /Marketplace Submission

### `GET` Marketplace Submission

**File:** `tools/simulation/user_journey.py`

---

## /N8N_API_KEY

### `GET` N8N_API_KEY

**File:** `tools/n8n_api.py`

### `GET` N8N_API_KEY

**File:** `tools/health_check.py`

---

## /N8N_API_URL

### `GET` N8N_API_URL

**File:** `tools/n8n_api.py`

### `GET` N8N_API_URL

**File:** `tools/health_check.py`

### `GET` N8N_API_URL

**File:** `tools/health_check.py`

### `GET` N8N_API_URL

**File:** `tools/health_check.py`

---

## /PREVIEW_DIR

### `GET` PREVIEW_DIR

**File:** `tools/marketplace_upload_previews.py`

---

## /Project Creation

### `GET` Project Creation

**File:** `tools/simulation/user_journey.py`

---

## /SKILL_NAME

### `GET` SKILL_NAME

**File:** `tools/skills/skill_manager.py`

---

## /SKILL_PATH

### `GET` SKILL_PATH

**File:** `tools/skills/skill_manager.py`

### `GET` SKILL_PATH

**File:** `tools/skills/installed/code-review/config.py`

### `GET` SKILL_PATH

**File:** `tools/skills/installed/code-review/review.py`

### `GET` SKILL_PATH

**File:** `tools/skills/installed/deploy-check/config.py`

### `GET` SKILL_PATH

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /Signup & Onboarding

### `GET` Signup & Onboarding

**File:** `tools/simulation/user_journey.py`

---

## /X-RateLimit-Remaining

### `GET` X-RateLimit-Remaining

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /X-RateLimit-Reset

### `GET` X-RateLimit-Reset

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /__Secure-authjs.session-token

### `GET` __Secure-authjs.session-token

**File:** `projects/task-tracker/src/middleware.ts`

---

## /access_count

### `GET` access_count

**File:** `tools/brain_quality.py`

### `GET` access_count

**File:** `tools/brain_quality.py`

---

## /alerts

### `GET` alerts

**File:** `tools/scaffold.py`

---

## /alerts_enabled

### `GET` alerts_enabled

**File:** `tools/scaffold.py`

---

## /api

### `POST` /api/keys

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/keys

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/keys/{key_id}

**File:** `projects/api-hub/backend/main.py`

### `DELETE` /api/keys/{key_id}

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys/{key_id}/deactivate

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys/{key_id}/activate

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys/{key_id}/log-usage

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/keys/{key_id}/usage

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/dashboard

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/keys

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/keys/{key_id}

**File:** `projects/api-hub/backend/main.py`

### `DELETE` /api/keys/{key_id}

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys/{key_id}/deactivate

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys/{key_id}/activate

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys/{key_id}/log-usage

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/keys/{key_id}/usage

**File:** `projects/api-hub/backend/main.py`

### `GET` /api/dashboard

**File:** `projects/api-hub/backend/main.py`

### `POST` /api/keys

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys

**File:** `projects/api-hub/tests/test_api.py`

### `POST` /api/keys

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys/1

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys/999

**File:** `projects/api-hub/tests/test_api.py`

### `POST` /api/keys/1/log-usage?tokens=1500&cost=0.003&endpoint=/chat/completions&status_code=200&response_time_ms=450

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys/1

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys/1/usage

**File:** `projects/api-hub/tests/test_api.py`

### `POST` /api/keys/1/deactivate

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys?active_only=true

**File:** `projects/api-hub/tests/test_api.py`

### `POST` /api/keys/1/activate

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys/1

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys?provider=openrouter

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/dashboard

**File:** `projects/api-hub/tests/test_api.py`

### `DELETE` /api/keys/4

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/keys/4

**File:** `projects/api-hub/tests/test_api.py`

### `DELETE` /api/keys/999

**File:** `projects/api-hub/tests/test_api.py`

### `GET` /api/videos

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/videos/scrape

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/news

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/news/trending

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/news/scrape

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/projects

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/projects/trending

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/projects/scrape

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/automation

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/automation/{automation_id}

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/automation

**File:** `projects/ai-dashboard/backend/main.py`

### `PATCH` /api/automation/{automation_id}

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/automation/{automation_id}/generate-video

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/automation/{automation_id}/video-status

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/automation/{automation_id}/approve

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/scheduler/status

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/scheduler/run/{job_id}

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/stats

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/videos

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/videos/scrape

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/news

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/news/trending

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/news/scrape

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/projects

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/projects/trending

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/projects/scrape

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/automation

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/automation/{automation_id}

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/automation

**File:** `projects/ai-dashboard/backend/main.py`

### `PATCH` /api/automation/{automation_id}

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/automation/{automation_id}/generate-video

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/automation/{automation_id}/video-status

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/automation/{automation_id}/approve

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/scheduler/status

**File:** `projects/ai-dashboard/backend/main.py`

### `POST` /api/scheduler/run/{job_id}

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/stats

**File:** `projects/ai-dashboard/backend/main.py`

### `GET` /api/automation

**File:** `projects/ai-dashboard/frontend/lib/api.ts`

### `POST` /api/automation

**File:** `projects/ai-dashboard/frontend/lib/api.ts`

### `GET` /api/stats

**File:** `projects/ai-dashboard/frontend/lib/api.ts`

### `GET` /api/scheduler/status

**File:** `projects/ai-dashboard/frontend/lib/api.ts`

---

## /apis

### `GET` apis

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` apis

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` apis

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` apis

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` apis

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` apis

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` apis

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` apis

**File:** `tools/skills/installed/doc-generator/readme.py`

---

## /args

### `GET` args

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` args

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` args

**File:** `tools/skills/installed/doc-generator/readme.py`

---

## /auth

### `POST` /auth/login

**File:** `tools/scaffold.py`

### `GET` /auth/me

**File:** `tools/scaffold.py`

### `POST` /auth/login

**File:** `tools/scaffold.py`

### `GET` /auth/me

**File:** `tools/scaffold.py`

---

## /authjs.session-token

### `GET` authjs.session-token

**File:** `projects/task-tracker/src/middleware.ts`

---

## /author

### `GET` author

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` author

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` author

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /authorization

### `GET` authorization

**File:** `tools/scaffold.py`

---

## /available

### `GET` available

**File:** `tools/analytics.py`

### `GET` available

**File:** `tools/analytics.py`

---

## /backend_url

### `GET` backend_url

**File:** `tools/project_registry.py`

---

## /backup_info

### `GET` backup_info

**File:** `tools/brain.py`

---

## /backup_required

### `GET` backup_required

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /batch_size

### `GET` batch_size

**File:** `tools/scaffold.py`

---

## /billing

### `POST` /billing/create-checkout-session

**File:** `tools/scaffold.py`

### `POST` /billing/create-checkout-session

**File:** `tools/scaffold.py`

---

## /bio

### `GET` bio

**File:** `projects/task-tracker/src/app/actions/profile.ts`

---

## /brain_contribution

### `GET` brain_contribution

**File:** `tools/mw.py`

### `GET` brain_contribution

**File:** `tools/project_registry.py`

### `GET` brain_contribution

**File:** `tools/project_registry.py`

### `GET` brain_contribution

**File:** `tools/project_registry.py`

---

## /brain_data

### `GET` brain_data

**File:** `tools/brain.py`

---

## /branch

### `GET` branch

**File:** `tools/auto_update.py`

---

## /buffer_size

### `GET` buffer_size

**File:** `tools/scaffold.py`

---

## /busiest_day

### `GET` busiest_day

**File:** `tools/analytics.py`

---

## /buyer_id

### `GET` buyer_id

**File:** `tools/credits_ledger.py`

---

## /cancelled

### `GET` cancelled

**File:** `tools/credits_ledger.py`

---

## /category

### `GET` category

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /channelId

### `GET` channelId

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` channelId

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /channelName

### `GET` channelName

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /channelTitle

### `GET` channelTitle

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /channel_id

### `GET` channel_id

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /channel_name

### `GET` channel_name

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /channel_subscribers

### `GET` channel_subscribers

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /chunkIndex

### `GET` chunkIndex

**File:** `projects/task-tracker/src/app/api/files/upload/route.ts`

---

## /classes

### `GET` classes

**File:** `tools/ai_docs.py`

### `GET` classes

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` classes

**File:** `tools/skills/installed/doc-generator/readme.py`

---

## /color

### `GET` color

**File:** `projects/task-tracker/src/app/actions/tags.ts`

---

## /commands

### `GET` commands

**File:** `tools/skills/skill_manager.py`

---

## /commentCount

### `GET` commentCount

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` commentCount

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /comment_count

### `GET` comment_count

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /comments_count

### `GET` comments_count

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` comments_count

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /commit

### `GET` commit

**File:** `tools/auto_update.py`

---

## /commonName

### `GET` commonName

**File:** `tools/e2e/test_marketplace_e2e.py`

---

## /condition

### `GET` condition

**File:** `tools/workflow_engine.py`

---

## /config_files

### `GET` config_files

**File:** `tools/ai_docs.py`

### `GET` config_files

**File:** `tools/ai_docs.py`

---

## /content

### `GET` content

**File:** `tools/module_registry.py`

### `GET` content

**File:** `tools/module_registry.py`

### `GET` content

**File:** `tools/module_registry.py`

### `GET` content

**File:** `tools/module_registry.py`

### `GET` content

**File:** `tools/brain_sync.py`

### `GET` content

**File:** `tools/brain_sync.py`

### `GET` content

**File:** `tools/brain.py`

### `GET` content

**File:** `tools/brain_semantic.py`

### `GET` content

**File:** `tools/brain_semantic.py`

### `GET` content

**File:** `tools/brain_semantic.py`

### `GET` content

**File:** `tools/brain_semantic.py`

### `GET` content

**File:** `tools/brain_semantic.py`

---

## /content-type

### `GET` content-type

**File:** `projects/ai-dashboard/backend/services/youtube_automation.py`

### `GET` content-type

**File:** `tools/e2e/test_marketplace_e2e.py`

---

## /contentDetails

### `GET` contentDetails

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /context

### `GET` context

**File:** `tools/module_registry.py`

### `GET` context

**File:** `tools/brain_sync.py`

### `GET` context

**File:** `tools/brain.py`

### `GET` context

**File:** `tools/brain_semantic.py`

### `GET` context

**File:** `tools/brain_semantic.py`

---

## /continue_on_error

### `GET` continue_on_error

**File:** `tools/scaffold.py`

### `GET` continue_on_error

**File:** `tools/workflow_engine.py`

---

## /create-checkout-session

### `POST` /create-checkout-session

**File:** `tools/scaffold.py`

### `POST` /create-checkout-session

**File:** `tools/scaffold.py`

---

## /created

### `GET` created

**File:** `tools/module_registry.py`

---

## /created_at

### `GET` created_at

**File:** `tools/brain.py`

### `GET` created_at

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` created_at

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` created_at

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /current

### `GET` current

**File:** `tools/dep_checker.py`

---

## /current_version

### `GET` current_version

**File:** `tools/dep_checker.py`

---

## /data

### `GET` data

**File:** `tools/n8n_api.py`

### `GET` data

**File:** `projects/ai-dashboard/backend/services/youtube_automation.py`

### `GET` data

**File:** `projects/ai-dashboard/backend/services/youtube_automation.py`

### `GET` data

**File:** `projects/ai-dashboard/backend/services/youtube_automation.py`

---

## /date_added

### `GET` date_added

**File:** `tools/brain.py`

### `GET` date_added

**File:** `tools/brain_semantic.py`

---

## /date_columns

### `GET` date_columns

**File:** `tools/scaffold.py`

---

## /date_updated

### `GET` date_updated

**File:** `tools/brain.py`

### `GET` date_updated

**File:** `tools/brain_semantic.py`

---

## /days

### `GET` days

**File:** `projects/task-tracker/src/app/api/analytics/export/route.ts`

---

## /dependencies

### `GET` dependencies

**File:** `tools/deploy.py`

### `GET` dependencies

**File:** `tools/project_archive.py`

### `GET` dependencies

**File:** `tools/auto_update.py`

### `GET` dependencies

**File:** `tools/doc_generator.py`

### `GET` dependencies

**File:** `tools/project_compare.py`

### `GET` dependencies

**File:** `tools/analytics.py`

### `GET` dependencies

**File:** `tools/dep_checker.py`

### `GET` dependencies

**File:** `tools/ai_docs.py`

### `GET` dependencies

**File:** `tools/ai_docs.py`

### `GET` dependencies

**File:** `tools/ai_docs.py`

### `GET` dependencies

**File:** `tools/ai_docs.py`

### `GET` dependencies

**File:** `tools/project_health.py`

### `GET` dependencies

**File:** `tools/project_health.py`

### `GET` dependencies

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /depends_on

### `GET` depends_on

**File:** `tools/workflow_engine.py`

---

## /deployment

### `GET` deployment

**File:** `tools/project_registry.py`

### `GET` deployment

**File:** `tools/project_registry.py`

---

## /description

### `GET` description

**File:** `tools/credits_ledger.py`

### `GET` description

**File:** `tools/workflow_engine.py`

### `GET` description

**File:** `tools/workflow_engine.py`

### `GET` description

**File:** `tools/project_registry.py`

### `GET` description

**File:** `tools/project_registry.py`

### `GET` description

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` description

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` description

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` description

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` description

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` description

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` description

**File:** `tools/security/dep_audit.py`

### `GET` description

**File:** `tools/skills/installed/doc-generator/generate.py`

### `GET` description

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` description

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` description

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` description

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` description

**File:** `projects/task-tracker/src/app/actions/tasks.ts`

### `GET` description

**File:** `projects/task-tracker/src/app/actions/tasks.ts`

---

## /details

### `GET` details

**File:** `tools/brain_semantic.py`

### `GET` details

**File:** `tools/e2e/run_all_tests.py`

### `GET` details

**File:** `tools/skills/installed/security-scan/scan.py`

---

## /devDependencies

### `GET` devDependencies

**File:** `tools/deploy.py`

### `GET` devDependencies

**File:** `tools/project_archive.py`

### `GET` devDependencies

**File:** `tools/doc_generator.py`

### `GET` devDependencies

**File:** `tools/project_compare.py`

### `GET` devDependencies

**File:** `tools/analytics.py`

### `GET` devDependencies

**File:** `tools/dep_checker.py`

### `GET` devDependencies

**File:** `tools/ai_docs.py`

### `GET` devDependencies

**File:** `tools/project_health.py`

### `GET` devDependencies

**File:** `tools/project_health.py`

### `GET` devDependencies

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /discovered

### `GET` discovered

**File:** `tools/brain_learner.py`

---

## /discriminator

### `GET` discriminator

**File:** `tools/scaffold.py`

---

## /docstring

### `GET` docstring

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` docstring

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` docstring

**File:** `tools/skills/installed/doc-generator/readme.py`

---

## /documentation_checks

### `GET` documentation_checks

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /duration

### `GET` duration

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` duration

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` duration

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /email

### `GET` email

**File:** `tools/scaffold.py`

---

## /endDate

### `GET` endDate

**File:** `projects/task-tracker/src/app/api/analytics/export/route.ts`

---

## /entries

### `GET` entries

**File:** `tools/mw.py`

### `GET` entries

**File:** `tools/module_registry.py`

### `GET` entries

**File:** `tools/brain_sync.py`

### `GET` entries

**File:** `tools/brain.py`

### `GET` entries

**File:** `tools/brain.py`

---

## /entry_count

### `GET` entry_count

**File:** `tools/brain.py`

---

## /entry_points

### `GET` entry_points

**File:** `tools/ai_docs.py`

### `GET` entry_points

**File:** `tools/ai_docs.py`

---

## /env

### `GET` env

**File:** `tools/n8n_api.py`

### `GET` env

**File:** `tools/health_check.py`

---

## /environment

### `GET` environment

**File:** `tools/workflow_engine.py`

---

## /error

### `GET` error

**File:** `tools/auto_lint_scheduler.py`

---

## /errors

### `GET` errors

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /etag

### `GET` etag

**File:** `projects/task-tracker/src/shared/lib/analytics/github.ts`

---

## /eventTypes

### `GET` eventTypes

**File:** `projects/task-tracker/src/app/api/analytics/export/route.ts`

---

## /event_id

### `GET` event_id

**File:** `tools/test_brain_webhook.py`

---

## /experience

### `GET` experience

**File:** `tools/scaffold.py`

---

## /failed

### `GET` failed

**File:** `tools/e2e/run_all_tests.py`

### `GET` failed

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /fields

### `GET` fields

**File:** `tools/scaffold.py`

---

## /file

### `GET` file

**File:** `tools/ai_review.py`

### `GET` file

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` file

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` file

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` file

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` file

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` file

**File:** `projects/task-tracker/src/app/actions/files.ts`

### `GET` file

**File:** `projects/task-tracker/src/app/api/files/upload/route.ts`

---

## /file_key

### `GET` file_key

**File:** `tools/marketplace_upload_previews.py`

---

## /filename

### `GET` filename

**File:** `projects/task-tracker/src/app/api/files/upload/route.ts`

---

## /files

### `GET` files

**File:** `tools/ai_docs.py`

### `GET` files

**File:** `tools/ai_docs.py`

### `GET` files

**File:** `tools/ai_docs.py`

### `GET` files

**File:** `tools/ai_docs.py`

### `GET` files

**File:** `tools/ai_docs.py`

---

## /files_fixed

### `GET` files_fixed

**File:** `tools/auto_lint_scheduler.py`

---

## /fill_value

### `GET` fill_value

**File:** `tools/scaffold.py`

---

## /fixed_versions

### `GET` fixed_versions

**File:** `tools/security/dep_audit.py`

---

## /forks_count

### `GET` forks_count

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /format

### `GET` format

**File:** `tools/scaffold.py`

### `GET` format

**File:** `projects/task-tracker/src/app/api/analytics/export/route.ts`

---

## /frameworks

### `GET` frameworks

**File:** `tools/ai_docs.py`

### `GET` frameworks

**File:** `tools/ai_docs.py`

### `GET` frameworks

**File:** `tools/ai_docs.py`

### `GET` frameworks

**File:** `tools/ai_docs.py`

---

## /frontend_url

### `GET` frontend_url

**File:** `tools/project_registry.py`

---

## /functions

### `GET` functions

**File:** `tools/ai_docs.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` functions

**File:** `tools/skills/installed/doc-generator/readme.py`

---

## /grade

### `GET` grade

**File:** `tools/simulation/install_simulator.py`

### `GET` grade

**File:** `tools/simulation/install_simulator.py`

### `GET` grade

**File:** `tools/simulation/install_simulator.py`

### `GET` grade

**File:** `tools/simulation/install_simulator.py`

---

## /has_updates

### `GET` has_updates

**File:** `tools/auto_update.py`

### `GET` has_updates

**File:** `tools/auto_update.py`

### `GET` has_updates

**File:** `tools/auto_update.py`

---

## /headers

### `GET` headers

**File:** `tools/scaffold.py`

### `GET` headers

**File:** `tools/scaffold.py`

---

## /health

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `tools/scaffold.py`

### `GET` /health

**File:** `projects/big-project/backend/main.py`

### `GET` /health

**File:** `projects/big-project/backend/main.py`

### `GET` /health

**File:** `projects/blog-platform/backend/main.py`

### `GET` /health

**File:** `projects/blog-platform/backend/main.py`

### `GET` /health

**File:** `projects/api-hub/backend/main.py`

### `GET` /health

**File:** `projects/api-hub/backend/main.py`

### `GET` /health

**File:** `projects/api-hub/tests/test_api.py`

---

## /hits

### `GET` hits

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /homepage

### `GET` homepage

**File:** `tools/dep_checker.py`

---

## /hottest_files

### `GET` hottest_files

**File:** `tools/analytics.py`

---

## /id

### `GET` id

**File:** `tools/module_registry.py`

### `GET` id

**File:** `tools/brain_sync.py`

### `GET` id

**File:** `tools/brain_sync.py`

### `GET` id

**File:** `tools/brain.py`

### `GET` id

**File:** `tools/brain.py`

### `GET` id

**File:** `tools/brain_semantic.py`

### `GET` id

**File:** `tools/brain_semantic.py`

### `GET` id

**File:** `tools/brain_semantic.py`

### `GET` id

**File:** `tools/brain_semantic.py`

### `GET` id

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` id

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` id

**File:** `projects/ai-dashboard/backend/services/youtube_automation.py`

### `GET` id

**File:** `tools/security/dep_audit.py`

---

## /in_progress

### `GET` in_progress

**File:** `tools/autoforge_api.py`

### `GET` in_progress

**File:** `tools/autocoder_api.py`

---

## /input

### `GET` input

**File:** `tools/scaffold.py`

---

## /input_schema

### `GET` input_schema

**File:** `tools/scaffold.py`

---

## /installed_version

### `GET` installed_version

**File:** `tools/auto_update.py`

### `GET` installed_version

**File:** `tools/auto_update.py`

### `GET` installed_version

**File:** `tools/security/dep_audit.py`

---

## /integrity_errors

### `GET` integrity_errors

**File:** `tools/credits_ledger.py`

### `GET` integrity_errors

**File:** `tools/credits_ledger.py`

---

## /items

### `GET` items

**File:** `tools/scaffold.py`

### `GET` items

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` items

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` items

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /language

### `GET` language

**File:** `tools/ai_review.py`

### `GET` language

**File:** `tools/ai_docs.py`

### `GET` language

**File:** `tools/ai_docs.py`

### `GET` language

**File:** `tools/ai_docs.py`

### `GET` language

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` language

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /languages

### `GET` languages

**File:** `tools/ai_docs.py`

### `GET` languages

**File:** `tools/ai_docs.py`

### `GET` languages

**File:** `tools/ai_docs.py`

---

## /last_date

### `GET` last_date

**File:** `tools/auto_update.py`

---

## /last_message

### `GET` last_message

**File:** `tools/auto_update.py`

---

## /last_run

### `GET` last_run

**File:** `tools/scaffold.py`

---

## /latest

### `GET` latest

**File:** `tools/dep_checker.py`

---

## /latestVersion

### `GET` latestVersion

**File:** `tools/health_check.py`

---

## /latest_version

### `GET` latest_version

**File:** `tools/auto_update.py`

### `GET` latest_version

**File:** `tools/auto_update.py`

### `GET` latest_version

**File:** `tools/dep_checker.py`

---

## /level

### `GET` level

**File:** `tools/scaffold.py`

---

## /license

### `GET` license

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` license

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` license

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /likeCount

### `GET` likeCount

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` likeCount

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /like_count

### `GET` like_count

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /line

### `GET` line

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` line

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` line

**File:** `tools/skills/installed/doc-generator/api.py`

---

## /lines

### `GET` lines

**File:** `tools/ai_review.py`

---

## /link

### `GET` link

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /location

### `GET` location

**File:** `tools/dep_checker.py`

---

## /login

### `POST` /login

**File:** `tools/scaffold.py`

### `POST` /login

**File:** `tools/scaffold.py`

---

## /main

### `GET` main

**File:** `tools/deploy.py`

---

## /marketplace

### `GET` marketplace

**File:** `tools/mw.py`

### `GET` marketplace

**File:** `tools/project_registry.py`

### `GET` marketplace

**File:** `tools/project_registry.py`

### `GET` marketplace

**File:** `tools/project_registry.py`

### `GET` marketplace

**File:** `tools/project_registry.py`

---

## /max_retries

### `GET` max_retries

**File:** `tools/scaffold.py`

---

## /mcpServers

### `GET` mcpServers

**File:** `tools/n8n_api.py`

### `GET` mcpServers

**File:** `tools/health_check.py`

---

## /me

### `GET` /me

**File:** `tools/scaffold.py`

### `PUT` /me

**File:** `tools/scaffold.py`

### `GET` /me

**File:** `tools/scaffold.py`

### `PUT` /me

**File:** `tools/scaffold.py`

---

## /message

### `GET` message

**File:** `projects/ai-dashboard/backend/services/youtube_automation.py`

---

## /metadata

### `GET` metadata

**File:** `tools/credits_ledger.py`

---

## /method

### `GET` method

**File:** `tools/skills/installed/doc-generator/generate.py`

### `GET` method

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` method

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` method

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` method

**File:** `tools/skills/installed/doc-generator/readme.py`

---

## /metrics

### `GET` /metrics

**File:** `tools/scaffold.py`

### `GET` /metrics

**File:** `tools/scaffold.py`

---

## /metrics:rate_limit_hits

### `GET` metrics:rate_limit_hits

**File:** `tools/scaffold.py`

---

## /metrics_file

### `GET` metrics_file

**File:** `tools/scaffold.py`

---

## /missing_metadata

### `GET` missing_metadata

**File:** `tools/project_registry.py`

---

## /modules

### `GET` modules

**File:** `tools/brain_learner.py`

### `GET` modules

**File:** `tools/module_registry.py`

### `GET` modules

**File:** `tests/test_module_registry.py`

### `GET` modules

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` modules

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` modules

**File:** `tools/skills/installed/doc-generator/readme.py`

---

## /monitoring

### `GET` monitoring

**File:** `tools/scaffold.py`

---

## /n8n-mcp

### `GET` n8n-mcp

**File:** `tools/n8n_api.py`

---

## /name

### `GET` name

**File:** `tools/project_archive.py`

### `GET` name

**File:** `tools/scaffold.py`

### `GET` name

**File:** `tools/scaffold.py`

### `GET` name

**File:** `tools/scaffold.py`

### `GET` name

**File:** `tools/workflow_engine.py`

### `GET` name

**File:** `tools/workflow_engine.py`

### `GET` name

**File:** `tools/workflow_engine.py`

### `GET` name

**File:** `tools/brain_learner.py`

### `GET` name

**File:** `tools/project_registry.py`

### `GET` name

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` name

**File:** `tools/skills/installed/doc-generator/api.py`

### `GET` name

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` name

**File:** `tools/skills/installed/doc-generator/readme.py`

### `GET` name

**File:** `projects/task-tracker/src/app/actions/tags.ts`

### `GET` name

**File:** `projects/task-tracker/src/app/actions/profile.ts`

---

## /nonexistent-999

### `DELETE` nonexistent-999

**File:** `tests/test_brain.py`

---

## /notAfter

### `GET` notAfter

**File:** `tools/e2e/test_marketplace_e2e.py`

---

## /null_strategy

### `GET` null_strategy

**File:** `tools/scaffold.py`

---

## /num_comments

### `GET` num_comments

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /objectID

### `GET` objectID

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /open_issues_count

### `GET` open_issues_count

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /order_id

### `GET` order_id

**File:** `tools/credits_ledger.py`

---

## /orders

### `POST` /orders

**File:** `tools/scaffold.py`

### `GET` /orders/{{order_id}}

**File:** `tools/scaffold.py`

### `POST` /orders

**File:** `tools/scaffold.py`

### `GET` /orders/{{order_id}}

**File:** `tools/scaffold.py`

---

## /output

### `GET` output

**File:** `tools/scaffold.py`

### `GET` output

**File:** `tools/e2e/run_all_tests.py`

---

## /output_schema

### `GET` output_schema

**File:** `tools/scaffold.py`

---

## /owner

### `GET` owner

**File:** `tools/project_registry.py`

---

## /package

### `GET` package

**File:** `tools/security/dep_audit.py`

---

## /params

### `GET` params

**File:** `tools/scaffold.py`

---

## /passed

### `GET` passed

**File:** `tools/e2e/run_all_tests.py`

### `GET` passed

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /passes

### `GET` passes

**File:** `tools/autoforge_api.py`

### `GET` passes

**File:** `tools/autocoder_api.py`

---

## /pattern

### `GET` pattern

**File:** `tools/brain.py`

---

## /pending_commits

### `GET` pending_commits

**File:** `tools/auto_update.py`

---

## /performance_checks

### `GET` performance_checks

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /points

### `GET` points

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /post_update

### `GET` post_update

**File:** `tools/auto_update.py`

---

## /pre_update

### `GET` pre_update

**File:** `tools/auto_update.py`

---

## /prefix

### `GET` prefix

**File:** `tools/scaffold.py`

---

## /preview_images

### `GET` preview_images

**File:** `tools/marketplace_upload_previews.py`

---

## /price

### `GET` price

**File:** `tools/scaffold.py`

---

## /processed_at

### `GET` processed_at

**File:** `tools/test_brain_webhook.py`

---

## /processing

### `GET` processing

**File:** `tools/scaffold.py`

---

## /products

### `POST` /products

**File:** `tools/scaffold.py`

### `GET` /products

**File:** `tools/scaffold.py`

### `GET` /products/{{product_id}}

**File:** `tools/scaffold.py`

### `POST` /products

**File:** `tools/scaffold.py`

### `GET` /products

**File:** `tools/scaffold.py`

### `GET` /products/{{product_id}}

**File:** `tools/scaffold.py`

---

## /projects

### `GET` projects

**File:** `tools/mw.py`

### `GET` projects

**File:** `tools/project_registry.py`

### `GET` projects

**File:** `tools/project_registry.py`

### `GET` projects

**File:** `tools/project_registry.py`

### `GET` projects

**File:** `tools/project_registry.py`

---

## /publishedAt

### `GET` publishedAt

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /published_at

### `GET` published_at

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` published_at

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /published_parsed

### `GET` published_parsed

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /pushed_at

### `GET` pushed_at

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` pushed_at

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /range

### `GET` range

**File:** `tools/dep_checker.py`

---

## /references

### `GET` references

**File:** `tools/brain.py`

### `GET` references

**File:** `tools/brain_semantic.py`

---

## /register

### `POST` /register

**File:** `tools/scaffold.py`

### `POST` /register

**File:** `tools/scaffold.py`

---

## /related_tx

### `GET` related_tx

**File:** `tools/credits_ledger.py`

---

## /released

### `GET` released

**File:** `tools/credits_ledger.py`

### `GET` released

**File:** `tools/credits_ledger.py`

### `GET` released

**File:** `tools/credits_ledger.py`

---

## /required

### `GET` required

**File:** `tools/scaffold.py`

---

## /required_files

### `GET` required_files

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /response_time_ms

### `GET` response_time_ms

**File:** `tools/e2e/test_marketplace_e2e.py`

---

## /retry_delay

### `GET` retry_delay

**File:** `tools/scaffold.py`

---

## /review

### `GET` review

**File:** `tools/ai_review.py`

---

## /run

### `GET` run

**File:** `tools/workflow_engine.py`

---

## /scan_output

### `GET` scan_output

**File:** `tools/skills/installed/security-scan/diff.py`

---

## /scanned_at

### `GET` scanned_at

**File:** `tools/project_registry.py`

---

## /score

### `GET` score

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` score

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /scores

### `GET` scores

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /scripts

### `GET` scripts

**File:** `tools/deploy.py`

### `GET` scripts

**File:** `tools/project_archive.py`

### `GET` scripts

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /search_query

### `GET` search_query

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /security_checks

### `GET` security_checks

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /security_score

### `GET` security_score

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /severity

### `GET` severity

**File:** `tools/dep_checker.py`

### `GET` severity

**File:** `tools/dep_checker.py`

### `GET` severity

**File:** `tools/dep_checker.py`

### `GET` severity

**File:** `tools/skills/installed/security-scan/scan.py`

---

## /snippet

### `GET` snippet

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /ssl_required

### `GET` ssl_required

**File:** `tools/skills/installed/deploy-check/check.py`

---

## /stack

### `GET` stack

**File:** `tools/project_registry.py`

---

## /staged

### `GET` staged

**File:** `tools/ai_review.py`

---

## /stargazers_count

### `GET` stargazers_count

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /startDate

### `GET` startDate

**File:** `projects/task-tracker/src/app/api/analytics/export/route.ts`

---

## /statistics

### `GET` statistics

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /status

### `GET` status

**File:** `tools/mw.py`

### `GET` status

**File:** `tools/autoforge_api.py`

### `GET` status

**File:** `tools/smoke_test_marketplace.py`

### `GET` status

**File:** `tools/smoke_test_marketplace.py`

### `GET` status

**File:** `tools/autocoder_api.py`

### `GET` status

**File:** `tools/module_registry.py`

### `GET` status

**File:** `tools/project_registry.py`

### `GET` status

**File:** `tools/project_registry.py`

### `GET` status

**File:** `tools/project_registry.py`

### `GET` status

**File:** `tools/project_registry.py`

### `GET` status

**File:** `tools/project_registry.py`

### `GET` status

**File:** `tools/brain.py`

### `GET` status

**File:** `tools/brain_semantic.py`

### `GET` status

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` status

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` status

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` status

**File:** `tools/simulation/install_simulator.py`

### `GET` status

**File:** `tools/simulation/install_simulator.py`

### `GET` status

**File:** `projects/task-tracker/src/app/actions/tasks.ts`

---

## /statusMessage

### `GET` statusMessage

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /steps

### `GET` steps

**File:** `tools/workflow_engine.py`

---

## /strict_validation

### `GET` strict_validation

**File:** `tools/scaffold.py`

---

## /sub

### `GET` sub

**File:** `tools/scaffold.py`

---

## /subscriberCount

### `GET` subscriberCount

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /subscription

### `GET` /subscription

**File:** `tools/scaffold.py`

### `GET` /subscription

**File:** `tools/scaffold.py`

---

## /success_rate

### `GET` success_rate

**File:** `tools/e2e/run_all_tests.py`

### `GET` success_rate

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /summary

### `GET` summary

**File:** `tools/dep_checker.py`

### `GET` summary

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` summary

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` summary

**File:** `tools/e2e/run_all_tests.py`

### `GET` summary

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /synced_ids

### `GET` synced_ids

**File:** `tools/brain_sync.py`

---

## /tags

### `GET` tags

**File:** `tools/module_registry.py`

### `GET` tags

**File:** `tools/module_registry.py`

### `GET` tags

**File:** `tools/project_registry.py`

### `GET` tags

**File:** `tools/brain_sync.py`

### `GET` tags

**File:** `tools/brain.py`

### `GET` tags

**File:** `tools/brain.py`

### `GET` tags

**File:** `tools/brain_semantic.py`

### `GET` tags

**File:** `tools/brain_semantic.py`

---

## /taskId

### `GET` taskId

**File:** `projects/task-tracker/src/app/actions/files.ts`

### `GET` taskId

**File:** `projects/task-tracker/src/app/api/files/upload/route.ts`

---

## /test-001

### `DELETE` test-001

**File:** `tests/test_brain.py`

---

## /thumbnailUrl

### `GET` thumbnailUrl

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /thumbnail_prompt

### `GET` thumbnail_prompt

**File:** `projects/ai-dashboard/backend/services/youtube_automation.py`

---

## /thumbnail_url

### `GET` thumbnail_url

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` thumbnail_url

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /thumbnails

### `GET` thumbnails

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /timeout

### `GET` timeout

**File:** `tools/workflow_engine.py`

---

## /timestamp

### `GET` timestamp

**File:** `tools/skills/installed/security-scan/diff.py`

---

## /title

### `GET` title

**File:** `tools/dep_checker.py`

### `GET` title

**File:** `tools/dep_checker.py`

### `GET` title

**File:** `tools/brain_sync.py`

### `GET` title

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` title

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` title

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` title

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

### `GET` title

**File:** `examples/cli-task-manager/src/models.py`

### `GET` title

**File:** `projects/task-tracker/src/app/actions/tasks.ts`

### `GET` title

**File:** `projects/task-tracker/src/app/actions/tasks.ts`

---

## /top_contributors

### `GET` top_contributors

**File:** `tools/analytics.py`

---

## /topics

### `GET` topics

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` topics

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /total

### `GET` total

**File:** `tools/brain_sync.py`

---

## /totalChunks

### `GET` totalChunks

**File:** `projects/task-tracker/src/app/api/files/upload/route.ts`

---

## /total_fixes

### `GET` total_fixes

**File:** `tools/auto_lint_scheduler.py`

### `GET` total_fixes

**File:** `tools/auto_lint_scheduler.py`

---

## /total_tests

### `GET` total_tests

**File:** `tools/e2e/run_all_tests.py`

### `GET` total_tests

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /transformations

### `GET` transformations

**File:** `tools/scaffold.py`

---

## /type

### `GET` type

**File:** `tools/ai_review.py`

### `GET` type

**File:** `tools/mw.py`

### `GET` type

**File:** `tools/scaffold.py`

### `GET` type

**File:** `tools/scaffold.py`

### `GET` type

**File:** `tools/scaffold.py`

### `GET` type

**File:** `tools/scaffold.py`

### `GET` type

**File:** `tools/brain_learner.py`

### `GET` type

**File:** `tools/module_registry.py`

### `GET` type

**File:** `tools/module_registry.py`

### `GET` type

**File:** `tools/project_registry.py`

### `GET` type

**File:** `tools/project_registry.py`

### `GET` type

**File:** `tools/project_registry.py`

### `GET` type

**File:** `tools/project_registry.py`

### `GET` type

**File:** `tools/project_registry.py`

### `GET` type

**File:** `tools/brain_sync.py`

### `GET` type

**File:** `tools/brain.py`

### `GET` type

**File:** `tools/brain.py`

### `GET` type

**File:** `tools/brain_semantic.py`

### `GET` type

**File:** `tools/brain_semantic.py`

### `GET` type

**File:** `tools/brain_semantic.py`

---

## /updateAvailable

### `GET` updateAvailable

**File:** `tools/health_check.py`

---

## /updated_at

### `GET` updated_at

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

### `GET` updated_at

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /updated_parsed

### `GET` updated_parsed

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /uploadDate

### `GET` uploadDate

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /upload_url

### `GET` upload_url

**File:** `tools/marketplace_upload_previews.py`

---

## /url

### `GET` url

**File:** `tools/dep_checker.py`

### `GET` url

**File:** `tools/project_registry.py`

### `GET` url

**File:** `projects/ai-dashboard/backend/scrapers/news_aggregator.py`

---

## /usability_score

### `GET` usability_score

**File:** `tools/simulation/scenarios/run_all_scenarios.py`

---

## /user-agent

### `GET` user-agent

**File:** `projects/task-tracker/src/shared/actions/feedback.ts`

---

## /username

### `GET` username

**File:** `tools/scaffold.py`

---

## /validation

### `GET` validation

**File:** `tools/scaffold.py`

---

## /variables

### `GET` variables

**File:** `tools/workflow_engine.py`

---

## /vendor_id

### `GET` vendor_id

**File:** `tools/scaffold.py`

---

## /vendors

### `POST` /vendors/register

**File:** `tools/scaffold.py`

### `GET` /vendors/{{vendor_id}}/onboarding-link

**File:** `tools/scaffold.py`

### `POST` /vendors/register

**File:** `tools/scaffold.py`

### `GET` /vendors/{{vendor_id}}/onboarding-link

**File:** `tools/scaffold.py`

---

## /version

### `GET` version

**File:** `tools/project_archive.py`

### `GET` version

**File:** `tools/health_check.py`

### `GET` version

**File:** `tools/dep_checker.py`

---

## /viewCount

### `GET` viewCount

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

### `GET` viewCount

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /view_count

### `GET` view_count

**File:** `projects/ai-dashboard/backend/scrapers/youtube_scraper.py`

---

## /visibility

### `GET` visibility

**File:** `tools/skills/installed/doc-generator/api.py`

---

## /vulnerabilities

### `GET` vulnerabilities

**File:** `tools/dep_checker.py`

### `GET` vulnerabilities

**File:** `tools/security/dep_audit.py`

---

## /wanted

### `GET` wanted

**File:** `tools/dep_checker.py`

---

## /watchers_count

### `GET` watchers_count

**File:** `projects/ai-dashboard/backend/scrapers/github_trending.py`

---

## /webhook

### `POST` /webhook/{workflow_name}

**File:** `tools/scaffold.py`

### `POST` /webhook

**File:** `tools/scaffold.py`

### `POST` /webhook/{workflow_name}

**File:** `tools/scaffold.py`

### `POST` /webhook

**File:** `tools/scaffold.py`

---

## /welcome_channel

### `GET` welcome_channel

**File:** `tools/scaffold.py`

---

## /working_directory

### `GET` working_directory

**File:** `tools/workflow_engine.py`

---

## /x-forwarded-for

### `GET` x-forwarded-for

**File:** `projects/task-tracker/src/middleware.ts`

---

## /x-ratelimit-limit

### `GET` x-ratelimit-limit

**File:** `projects/task-tracker/src/shared/lib/analytics/github.ts`

---

## /x-ratelimit-remaining

### `GET` x-ratelimit-remaining

**File:** `projects/task-tracker/src/shared/lib/analytics/github.ts`

---

## /x-ratelimit-reset

### `GET` x-ratelimit-reset

**File:** `projects/task-tracker/src/shared/lib/analytics/github.ts`

---

## /x-ratelimit-used

### `GET` x-ratelimit-used

**File:** `projects/task-tracker/src/shared/lib/analytics/github.ts`

---

